// Cumulative Normal Distribution Function

// Copyright (C) 1999 by Makoto Nagata, MicroNova <mnagata@micronova.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESCuS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit http://www.micronova.com for updates

package com.micronova.math;

/**
   An implementation of Cumulative Normal Function
   (accurate up to 6 decimal places).
*/

public class CumulativeNormal implements DeltaCurve
{
    public final double getValueOf(double x)
    {
        double nx = Math.exp(- x * x / 2) / 2.5066282746310005024157652;

        if (x > 0)
        {
            double y = 1 / (1 + 0.2316419 * x);

            return 1.0 - (((((1.330274429 * y - 1.821255978) 
                * y + 1.781477937) * y - 0.356563782) * y + 0.319381530) * y) 
                * nx;
        }
        else
        {
            double y = 1 / (1 - 0.2316419 * x);

            return  (((((1.330274429 * y - 1.821255978) * y 
                        + 1.781477937) * y - 0.356563782) * y 
                      + 0.319381530) * y) * nx;
        }
    }

    public final double getDeltaOf(double x)
    {
        return Math.exp(- x * x / 2) / 2.5066282746310005024157652;
    }
}
